==> gulp-sass-5.0.0.tgz: gulp-sass/README.md <==
# Installation
> `npm install --save @types/gulp-sass`

# Summary
This package contains type definitions for gulp-sass (https://github.com/dlmanning/gulp-sass).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-sass.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-sass/index.d.ts)
````ts
// Type definitions for gulp-sass 5.0.0
// Project: https://github.com/dlmanning/gulp-sass
// Definitions by: Asana <https://asana.com>
//                 Yuma Hashimoto <https://github.com/yuma84>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.7

/// <reference types="node"/>

import { Options } from 'node-sass';

interface SassResults {
    css: string;
    map: string;
    stats: {
        entry: string;
        start: Date;
        end: Date;
        duration: number;
        includedFiles: string[];
    }
}

interface SassOptions extends Options {
    success?: ((results: SassResults) => any) | undefined;
    error?: ((err: Error) => any) | undefined;
    imagePaths?: string[] | undefined;
}

interface GulpSassOptions extends SassOptions {
    errLogToConsole?: boolean | undefined;
    onSuccess?: ((css: string) => any) | undefined;
    onError?: ((err: Error) => any) | undefined;
    sync?: boolean | undefined;
}

interface GulpSass {
    (opts?: GulpSassOptions): NodeJS.ReadWriteStream;
    logError(error?: string): void;
    sync(options?: GulpSassOptions): NodeJS.ReadWriteStream;
}

type Compiler = any;

interface GulpSassFactory {
    (compiler: Compiler): GulpSass
}

declare var _tmp: GulpSassFactory;
export = _tmp;

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 14:22:34 GMT
 * Dependencies: [@types/node-sass](https://npmjs.com/package/@types/node-sass), [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [Asana](https://asana.com), and [Yuma Hashimoto](https://github.com/yuma84).

==> gulp-sass-5.0.1.tgz: gulp-sass/README.md <==
# Installation
> `npm install --save @types/gulp-sass`

# Summary
This package contains type definitions for gulp-sass (https://github.com/dlmanning/gulp-sass).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-sass.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/gulp-sass/index.d.ts)
````ts
// Type definitions for gulp-sass 5.0.0
// Project: https://github.com/dlmanning/gulp-sass
// Definitions by: Asana <https://asana.com>
//                 Yuma Hashimoto <https://github.com/yuma84>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.7

/// <reference types="node"/>

import { Options } from 'node-sass';

interface SassResults {
    css: string;
    map: string;
    stats: {
        entry: string;
        start: Date;
        end: Date;
        duration: number;
        includedFiles: string[];
    }
}

interface SassOptions extends Options {
    success?: ((results: SassResults) => any) | undefined;
    error?: ((err: Error) => any) | undefined;
    imagePaths?: string[] | undefined;
}

interface GulpSassOptions extends SassOptions {
    errLogToConsole?: boolean | undefined;
    onSuccess?: ((css: string) => any) | undefined;
    onError?: ((err: Error) => any) | undefined;
    sync?: boolean | undefined;
}

interface GulpSass {
    (opts?: GulpSassOptions): NodeJS.ReadWriteStream;
    logError(error?: string): void;
    sync(options?: GulpSassOptions): NodeJS.ReadWriteStream;
}

type Compiler = any;

interface GulpSassFactory {
    (compiler: Compiler): GulpSass
}

declare var _tmp: GulpSassFactory;
export = _tmp;

````

### Additional Details
 * Last updated: Wed, 10 May 2023 21:03:35 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node), [@types/node-sass](https://npmjs.com/package/@types/node-sass)
 * Global values: none

# Credits
These definitions were written by [Asana](https://asana.com), and [Yuma Hashimoto](https://github.com/yuma84).
